@@ -23,9 +23,12 @@ except ImportError:
 import argparse
 
 def prepend_to_file_name(full_path, to_prepend):
-        dir_name, file_name = full_path.split("/")
-        file_name = to_prepend + file_name
-        return dir_name + "/" + file_name
+    if "/" in full_path:
+        path, file = full_path.rsplit('/', 1)
+        return f"{path}/{to_prepend}_{file}"
+    else:
+        return f"{to_prepend}_{full_path}"
+
 
 def main():
     print(f"Chronumental {version}")
@@ -69,12 +72,12 @@ def main():
                         type=float,
                         help="Scale factor for branch length distribution")
 
-    parser.add_argument('-s',
+    parser.add_argument('--steps',
                         default=1000,
                         type=int,
                         help="Number of steps to use for the SVI")
 
-    parser.add_argument('-lr',
+    parser.add_argument('--lr',
                         default=0.1,
                         type=float,
                         help="Adam learning rate")
@@ -83,6 +86,8 @@ def main():
     substitutions_per_site_per_year = args.c
     genome_size = args.g
 
+   
+
     print("Reading metadata")
     metadata = pd.read_table(args.dates, low_memory=False)
 
@@ -125,6 +130,8 @@ def main():
         terminal_targets = {}
         for terminal in tqdm.tqdm(tree.root.get_terminals(),
                                   "Creating target date array"):
+            
+            terminal.name = terminal.name.replace("'", "")
             if terminal.name in lookup:
                 date = lookup[terminal.name]
                 diff = (date - lookup[reference_point]).days
@@ -133,8 +140,10 @@ def main():
 
     target_dates = get_target_dates()
     terminal_names = target_dates.keys()
+    
     terminal_target_dates_array = jnp.asarray(
         [float(target_dates[x]) for x in terminal_names])
+    print(f"Found {len(terminal_names)} terminals")
     terminal_name_to_pos = {x: i for i, x in enumerate(terminal_names)}
 
     def assign_paths(tree):
@@ -155,6 +164,8 @@ def main():
                              "finding initial branch_lengths"):
         if node.name == "":
             node.name = f"internal_node_{i}"
+        if node.branch_length is None:
+            node.branch_length = 0
         initial_branch_lengths[node.name] = node.branch_length
     names_init = initial_branch_lengths.keys()
     branch_distances_array = np.array(
@@ -191,6 +202,12 @@ def main():
     substitutions_per_site_per_year = 1e-3
     genome_size = 30000
 
+    print(branch_distances_array)
+
+    print(genome_size)
+
+    print(substitutions_per_site_per_year)
+
     initial_time = 365 * (
         branch_distances_array / genome_size
     ) / substitutions_per_site_per_year + 3  # We add 3 to this prior because tranmsmission after zero days is relatively unlikely
@@ -230,7 +247,7 @@ def main():
     svi = SVI(model, guide, optim.Adam(args.lr), Trace_ELBO())
     state = svi.init(jax.random.PRNGKey(0))
 
-    num_steps = args.s
+    num_steps = args.steps
     for step in range(num_steps):
         state, loss = svi.update(state)
         if step % 10 == 0:
@@ -271,5 +288,13 @@ def main():
         output_handle = open(output_tree, "w")
     Phylo.write(tree2, output_handle, "newick")
 
+    new_dates_absolute = [lookup[reference_point] + datetime.timedelta(days=x) for x in new_dates.tolist()]
+    
+    output_meta = pd.DataFrame({'strain': terminal_names,
+                                'date': new_dates_absolute})
+
+    output_meta_file = prepend_to_file_name(args.tree,"timetree_meta_")
+    output_meta.to_csv(f"{output_meta_file}.tsv", sep="\t", index=False)
+
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
